==> vtk-v4.0.2.zip: vtk-v4.0.2/Rendering/vtkMesaRenderer.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkMesaRenderer.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$


Copyright (c) 1993-2001 Ken Martin, Will Schroeder, Bill Lorensen 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither name of Ken Martin, Will Schroeder, or Bill Lorensen nor the names
   of any contributors may be used to endorse or promote products derived
   from this software without specific prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// Make sure this is first, so any includes of gl.h can be stoped if needed
#define VTK_IMPLEMENT_MESA_CXX

#include "MangleMesaInclude/gl_mangle.h"
#include "MangleMesaInclude/gl.h"

#include <math.h>
#include "vtkToolkits.h"
#include "vtkMesaRenderer.h"
#include "vtkRenderWindow.h"
#include "vtkMesaProperty.h"
#include "vtkMesaCamera.h"
#include "vtkMesaLight.h"
#include "vtkCuller.h"


// make sure this file is included before the #define takes place
// so we don't get two vtkMesaRenderer classes defined.
#include "vtkOpenGLRenderer.h"
#include "vtkMesaRenderer.h"

// Make sure vtkMesaRenderer is a copy of vtkOpenGLRenderer
// with vtkOpenGLRenderer replaced with vtkMesaRenderer
#define vtkOpenGLRenderer vtkMesaRenderer
#include "vtkOpenGLRenderer.cxx"
#undef vtkOpenGLRenderer

//---------------------------------------------------------------------------
vtkMesaRenderer* vtkMesaRenderer::New()
{
  // First try to create the object from the vtkObjectFactory
  vtkObject* ret = vtkObjectFactory::CreateInstance("vtkMesaRenderer");
  if(ret)
    {
    return (vtkMesaRenderer*)ret;
    }
  // If the factory was unable to create the object, then create it here.
  return new vtkMesaRenderer;
}

vtkCamera *vtkMesaRenderer::MakeCamera()
{
  return vtkMesaCamera::New();
}

vtkLight *vtkMesaRenderer::MakeLight()
{
  return vtkMesaLight::New();
}

==> vtk-v4.2.2.zip: vtk-v4.2.2/Rendering/vtkMesaRenderer.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkMesaRenderer.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

  Copyright (c) 1993-2002 Ken Martin, Will Schroeder, Bill Lorensen 
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even 
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// Make sure this is first, so any includes of gl.h can be stoped if needed
#define VTK_IMPLEMENT_MESA_CXX

#include "MangleMesaInclude/gl_mangle.h"
#include "MangleMesaInclude/gl.h"

#include <math.h>
#include "vtkToolkits.h"
#include "vtkMesaRenderer.h"
#include "vtkRenderWindow.h"
#include "vtkMesaProperty.h"
#include "vtkMesaCamera.h"
#include "vtkMesaLight.h"
#include "vtkCuller.h"


// make sure this file is included before the #define takes place
// so we don't get two vtkMesaRenderer classes defined.
#include "vtkOpenGLRenderer.h"
#include "vtkMesaRenderer.h"

// Make sure vtkMesaRenderer is a copy of vtkOpenGLRenderer
// with vtkOpenGLRenderer replaced with vtkMesaRenderer
#define vtkOpenGLRenderer vtkMesaRenderer
#include "vtkOpenGLRenderer.cxx"
#undef vtkOpenGLRenderer

vtkCxxRevisionMacro(vtkMesaRenderer, "1.13");
vtkStandardNewMacro(vtkMesaRenderer);

vtkCamera *vtkMesaRenderer::MakeCamera()
{
  return vtkMesaCamera::New();
}

vtkLight *vtkMesaRenderer::MakeLight()
{
  return vtkMesaLight::New();
}
